pyprocar.core.BrillouinZone — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# pyprocar.core.BrillouinZone

class pyprocar.core.BrillouinZone(*args, **kwargs)

  A Surface object with verts, faces and line representation, representing the BrillouinZone. This class will calculate the BrillouinZone corresponding to a reciprocal lattice.

  Parameters:

    - reciprocal_lattice (np.ndarray,) – Reciprocal lattice used to generate Brillouin zone usgin Wigner Seitz. (3,3) float

    - transformation_matrix (np.ndarray) – Any transformation to be applied to the unit cell such as rotation or supercell. (3,3) float. defaults to None

  Methods

  `BrillouinZone.__init__`(reciprocal_lattice[, ...]) | Initialize the polydata.
  `BrillouinZone.wigner_seitz`() | Calculates the wigner Seitz cell in the form of a tuple containing the verts and faces of the cell

  Attributes